# python-task-manager
Task Manager is a wrapper that executes your tasks and rollback functions in a safe way


## Using

More usage examples can be found in this repository. You may also explore the tests/ folder to get a better view of this library.


## Developing

Feel free to suggest modifications and/or merge/pull requests.

```bash
# start venv
python3 -m venv venv
source ./venv/bin/activate

# install pipenv 
python3 -m pip install pipenv

# install the rest of the dependencies (with dev deps too)
python3 -m pipenv install -d

# to test this package installed
python3 -m pip install .
```

